# Copyright 2007, 2008 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls WASKA (CoMPUter-based case fiLeS -
# Web-Anwendungs-Server fuer Kompetenzagenturen).
#
# mpuls WASKA is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls WASKA is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls WASKA. If not, see <http://www.gnu.org/licenses/>.
#
# mpuls WASKA has been developed on behalf of the
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and
# European Social Fund resources.

"""Routes configuration

The more specific and detailed routes should be defined first so they
may take precedent over the more generic routes. For more information
refer to the routes manual at http://routes.groovie.org/docs/
"""

import os
import re
import logging

from pylons import config
from routes import Mapper

import mpulsweb.controllers

log = logging.getLogger(__name__)

def controller_scan(directory=None):
    """Scan a directory for python files and use them as controllers"""
    log.debug('Scanning for controllers in %s' % directory)
    controllers = []
    if directory is None:
        return []

    def find_controllers(dirname, prefix=''):
        """Locate controllers in a directory"""
        controllers = []
        for fname in os.listdir(dirname):
            filename = os.path.join(dirname, fname)
            if os.path.isfile(filename) and \
                re.match('^[^_]{1,1}.*\.py$', fname):
                controllers.append(prefix + fname[:-3])
            elif os.path.isdir(filename):
                controllers.extend(find_controllers(filename,
                                                    prefix=prefix + fname +'/'))
        return controllers

    def longest_first(fst, lst):
        """Compare the length of one string to another, shortest goes first"""
        return cmp(len(lst), len(fst))

    for dirname in directory:
        controllers.extend(find_controllers(dirname))
    controllers.sort(longest_first)
    log.debug('Found controllers: %s' % controllers)
    return controllers

def make_map():
    """Create, configure and return the routes Mapper"""
    # First try to search to controllers in the instance (WASKO, WASKA, JMD ...)
    controller_dirs = []
    basepath = config['pylons.paths']['controllers']
    controller_dirs.append(basepath)
    # Then append controllers in the Baseapplication
    controller_dirs.append(os.path.dirname(mpulsweb.controllers.__file__))
    # Remove duplicate in controller dirs
    controller_dirs = list(set(controller_dirs))
    map = Mapper(controller_scan=controller_scan,
                 directory=controller_dirs,
                 always_scan=config['debug'])

    # The ErrorController route (handles 404/500 error pages); it should
    # likely stay at the top, ensuring it can always be resolved
    map.connect('/error/{action}', controller='error')
    map.connect('/error/{action}/{id}', controller='error')

    # CUSTOM ROUTES HERE

    map.connect('/', controller=config.get('mpuls.app.indexcontroller',
                                           'mpuls'),
                action='index')
    # Explicit route for case overview actions because the generic
    # '/{controller}/{action}/{id}' doesn't work for them.
    map.connect('/case_overview/{action}/{confirmed}',
                controller="case_overview")
    map.connect('/case_bundle/{action}/{confirmed}',
                controller="case_bundle")

    map.connect('/phase/setPhase/{id}/{value}', controller="phase", action="setPhase")
    map.connect('/{controller}', action='index')
    map.connect('/{controller}/{action}')
    map.connect('/{controller}/{action}/{id}')
    map.connect('/{controller}/{action}/{id}/{confirmed}')
    map.connect('/{controller}/{action}/{id}/*url') # used for dowloading files

    return map
