
RELATIONS = (
    'master_tbl',
    'rg_adresse_betr_person_tbl',
    'rg_adresse_mutter_tbl',
    'rg_adresse_vater_tbl',
    'rg_fehlzeiten_tbl',
    'rg_institution_tbl',
    'rg_kd_bezugsperson_tbl',
    'rg_kompetenz_tbl',
    'rg_telefon_betr_person_tbl',
    'rg_telefon_mutter_tbl',
    'rg_telefon_vater_tbl',
    'rg_unterstuetzung_tbl')

class Data(object):
    pass

class RelationType(type):

    def __new__(mcs, name, bases, dict):
        for relation in RELATIONS:
            dict[relation] = lambda x, y: x.get_relation(relation, y)
        return type.__new__(mcs, name, bases, dict)

class Context(object):

    __metaclass__ = RelationType
    
    def __init__(self, relations = None):
        if relations is None: relations = {}
        self.relations = relations

    def get_relation(self, relation, key):
        try:
            rel = self.relations[key]
        except KeyError:
            rel = {}
            self.relations[relation] = rel
        try:
            data = rel[key]
        except KeyError:
            data = Data()
            rel[key] = data
        return data

# Schulen und Jugendaemter werden in die rg_institution_tbl kopiert.
# Um Ueberlappungen aus dem Weg zu gehen, werden Offsets
# eingefuehrt.

SCHULE_OFS = 10000
JUGEND_OFS = 20000

# FILL THE FOLLOWING FUNCTIONS WITH THE SPECIFIC CONVERSIONS:

def kd_institution_email_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_institution_tbl(parameters[0])
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    rg.inst_dokumentation = prefix and "%s\n%s" % (prefix, value) or value

def kd_institution_name_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_institution_tbl(parameters[0])
    rg.institution = value

def kd_institution_ort_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_institution_tbl(parameters[0])
    rg.inst_ort = value

def kd_institution_plz_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_institution_tbl(parameters[0])
    rg.inst_plz = value

def kd_institution_strasse_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_institution_tbl(parameters[0])
    rg.inst_strasse = value

def kd_institution_vorwahl_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_institution_tbl(parameters[0])
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    txt = "(%s)" % value
    rg.inst_dokumentation = prefix and "%s\n%s" % (prefix, txt) or txt

def kd_institution_kundennummer_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_institution_tbl(parameters[0])
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    txt = "Kundennummer: %s" % value
    rg.inst_dokumentation = prefix and "%s\n%s" % (prefix, txt) or txt

def kd_institution_strassenr_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_institution_tbl(parameters[0])
    rg.inst_strassennr = value

def kd_institution_telefonnummer_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_institution_tbl(parameters[0])
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    rg.inst_dokumentation = prefix and "%s\n%s" % (prefix, value) or value

def kd_bezug_email_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_email = value

def kd_bezug_strasse_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_strasse = value

def kd_bezug_plz_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_plz = value

def kd_bezug_strassenr_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_strassennr = value

def kd_bezug_ort_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_ort = value

def kd_bezug_vorname_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_vorname = value

def kd_bezug_name_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_name = value

def kd_bezug_funktion_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_funktion = value

def kd_bezug_A_telefon(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_telefon = value

def kd_bezug_A_vorwahl(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_kd_bezugsperson_tbl(parameters[0])
    rg.kd_bezug_vorwahl = value

def kd_jugendamt_vorwahl_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + JUGEND_OFS)
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    txt = "(%s)" % value
    rg.inst_dokumentation = prefix and "%s\n%s" % (prefix, txt) or txt

def kd_jugendamt_strasse_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + JUGEND_OFS)
    rg.inst_strasse = value
    rg.institution  = "Jugendamt"

def kd_jugendamt_strassenr_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + JUGEND_OFS)
    rg.inst_strassenr = value
    rg.institution    = "Jugendamt"

def kd_jugendamt_email_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + JUGEND_OFS)
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    rg.inst_dokumentation = prefix and "%s\n%s" % (prefix, value) or value

def kd_jugendamt_plz_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + JUGEND_OFS)
    rg.inst_plz    = value
    rg.institution = "Jugendamt"

def kd_jugendamt_ort_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + JUGEND_OFS)
    rg.inst_ort    = value
    rg.institution = "Jugendamt"

def kd_jugendamt_kundennummer_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + JUGEND_OFS)
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    txt = "Kundennummer: %s" % value
    rg.inst_dokumentation = prefix and "%s\n%s" % (prefix, txt) or txt

def kd_jugendamt_telefonnummer_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + JUGEND_OFS)
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    rg.inst_dokumentation = prefix and "%s\n%s" % (prefix, value) or value

def kd_schule_vorwahl_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    rg.inst_dokumentation = prefix and '%s\n%s' % (prefix, value) or value

def kd_schule_strasse_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.inst_strasse = value

def kd_schule_strassenr_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.inst_strassenr = value

def kd_schule_email_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    rg.inst_dokumentation = prefix and '%s\n%s' % (prefix, value) or value

def kd_schule_plz_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.inst_plz = value

def kd_schule_ort_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.inst_ort = value

def kd_schule_name_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.institution = value

def kd_schule_telefonnummer_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    prefix = hasattr(rg, "inst_dokumentation") and rg.inst_dokumentation or ''
    rg.inst_dokumentation = prefix and '%s\n%s' % (prefix, value) or value

def fehlutg_A(value, parameters, context):
    # parameters: (1,), (10,), (11,), (12,), (13,), (14,), (15,), (16,), (17,), (18,), (2,), (3,), (4,), (5,), (6,), (7,), (8,), (9,)
    rg = context.rg_fehlzeiten_tbl(parameters[0])
    rg.fehlutg = value

def fehlA_B(value, parameters, context):
    # parameters: ('j', 1), ('j', 10), ('j', 11), ('j', 12), ('j', 13), ('j', 14), ('j', 15), ('j', 16), ('j', 17), ('j', 18), ('j', 2), ('j', 3), ('j', 4), ('j', 5), ('j', 6), ('j', 7), ('j', 8), ('j', 9), ('m', 1), ('m', 10), ('m', 11), ('m', 12), ('m', 13), ('m', 14), ('m', 15), ('m', 16), ('m', 17), ('m', 18), ('m', 2), ('m', 3), ('m', 4), ('m', 5), ('m', 6), ('m', 7), ('m', 8), ('m', 9)
    rg = context.rg_fehlzeiten_tbl(parameters[1])
    setattr(rg, "fehl%s" % parameters[0], value)

def fehltg_A(value, parameters, context):
    # parameters: (1,), (10,), (11,), (12,), (13,), (14,), (15,), (16,), (17,), (18,), (2,), (3,), (4,), (5,), (6,), (7,), (8,), (9,)
    rg = context.rg_fehlzeiten_tbl(parameters[0])
    rg.fehltg = value

def fehlfust_A(value, parameters, context):
    # parameters: (1,), (10,), (11,), (12,), (13,), (14,), (15,), (16,), (17,), (18,), (2,), (3,)), (4,), (5,), (6,), (7,), (8,), (9,)
    rg = context.rg_fehlzeiten_tbl(parameters[0])
    rg.fehlfust = value

def fehlst_A(value, parameters, context):
    # parameters: (1,), (10,), (11,), (12,), (13,), (14,), (15,), (16,), (17,), (18,), (2,), (3,), (4,), (5,), (6,), (7,), (8,), (9,)
    rg = context.rg_fehlzeiten_tbl(parameters[0])
    rg.fehlst = value

def entw_beh(value, parameters, context):
    # parameters: ()
    rg = context.rg_kompetenz_tbl((1,))
    rg.entw_beh = value

def entw_A_B(value, parameters, context):
    # parameters: ('a', 1), ('b', 1), ('c', 1), ('d', 1), ('e', 1), ('f', 1), ('g', 1), ('h', 1), ('i', 1), ('j', 1), ('k', 1)
    rg = context.rg_kompetenz_tbl(parameters[1])
    setattr(rg, "entw_%s" % parameters[0], value)

def entw_A_t_B(value, parameters, context):
    # parameters: ('h', 1), ('i', 1), ('j', 1), ('k', 1)
    rg = context.rg_kompetenz_tbl(parameters[1])
    setattr(rg, "entw_%s_t" % parameters[0], value)

def hilfm_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    # XXX: Do not map!
    pass

def hilfm_ende_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    rg.hilfm_ende = value

def hilfm_start_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    rg.hilfm_start = value

def hilfm_sf_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    rg.hilfm_sf = value

def hilfm_umf_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    rg.hilfm_umf = value

def hilfm_erreicht_A_B(value, parameters, context):
    # parameters: (1, 1), (1, 2), (1, 3), (2, 1), (2, 2), (2, 3), (3, 1), (3, 2), (3, 3)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    setattr(rg, "hilfm_erreicht_%d" % parameters[1], value)

def hilfm_ziel_A_B(value, parameters, context):
    # parameters: (1, 1), (1, 2), (1, 3), (2, 1), (2, 2), (2, 3), (3, 1), (3, 2), (3, 3)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    setattr(rg, "hilfm_ziel_%d" % parameters[1], value)

def hilfm_inst_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    rg.hilfm_inst = value

def hilfm_zeit_A_B(value, parameters, context):
    # parameters: (1, 1), (1, 2), (1, 3), (2, 1), (2, 2), (2, 3), (3, 1), (3, 2), (3, 3)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    setattr(rg, "hilfm_zeit_%d" % parameters[1], value)

def hilfm_art_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    rg.hilfm_art = value

def hilfm_einr_A(value, parameters, context):
    # parameters: (1,), (2,), (3,)
    rg = context.rg_unterstuetzung_tbl(parameters[0])
    rg.hilfm_einr = value

def komp_schule_A_B(value, parameters, context):
    # parameters: ('a', 1), ('b', 1), ('c', 1), ('d', 1), ('e', 1), ('f', 1), ('g', 1)
    rg = context.rg_kompetenz_tbl(parameters[1])
    setattr(rg, "komp_schule_%s" % parameters[0], value)

def komp_sozial_A_B(value, parameters, context):
    # parameters: ('a', 1), ('b', 1), ('c', 1), ('d', 1), ('e', 1), ('f', 1), ('g', 1)
    rg = context.rg_kompetenz_tbl(parameters[1])
    setattr(rg, "komp_sozial_%s" % parameters[0], value)

def komp_deutsch_A_B(value, parameters, context):
    # parameters: ('a', 1), ('b', 1), ('c', 1), ('d', 1)
    rg = context.rg_kompetenz_tbl(parameters[1])
    setattr(rg, "komp_deutsch_%s" % parameters[0], value)

def komp_selbst_A_B(value, parameters, context):
    # parameters: ('a', 1), ('b', 1), ('c', 1), ('d', 1), ('e', 1), ('f', 1), ('g', 1)
    rg = context.rg_kompetenz_tbl(parameters[1])
    setattr(rg, "komp_selbst_%s" % parameters[0], value)

def komp_psy_A_B(value, parameters, context):
    # parameters: ('a', 1), ('b', 1), ('c', 1), ('d', 1), ('e', 1), ('f', 1), ('g', 1)
    rg = context.rg_kompetenz_tbl(parameters[1])
    setattr(rg, "komp_psy_%s" % parameters[0], value)

def komp_herkunft_A(value, parameters, context):
    # parameters: ((1,))
    rg = context.rg_kompetenz_tbl(parameters[0])
    rg.komp_herkunft = value

def komp_X_g_t_1(value, parameters, context):
    # parameters: ('psy',), ('schule',), ('selbst',), ('sozial',)
    rg = context.rg_kompetenz_tbl((1,))
    setattr(rg, "komp_%s_g_t" % parameters[0], value)

def komp_anm(value, parameters, context):
    # parameters: ()
    rg = context.rg_kompetenz_tbl((1,))
    rg.komp_anm = value

def datum_kf_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_kompetenz_tbl(parameters[0])
    rg.datum_kf = value

def kf_anbiet_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_kompetenz_tbl(parameters[0])
    rg.kf_anbiet = value

def kf_verfahren_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_kompetenz_tbl(parameters[0])
    rg.kf_anbiet = value

def kf_meth_A_1(value, parameters, context):
    # parameters: ('a',), ('b',), ('d',), ('e',), ('f',)
    rg = context.rg_kompetenz_tbl((1,))
    setattr(rg, "komp_meth_%s" % parameters[0], value)

def kf_test_A_1(value, parameters, context):
    # parameters: ('a',), ('b',), ('c',), ('d',)
    rg = context.rg_kompetenz_tbl((1,))
    setattr(rg, "komp_test_%s" % parameters[0], value)

def kf_test_A_t_1(value, parameters, context):
    # parameters: ('a',), ('b',), ('c',), ('d',)
    rg = context.rg_kompetenz_tbl((1,))
    setattr(rg, "komp_test_%s_t" % parameters[0], value)

def kf_meth_A_t_1(value, parameters, context):
    # parameters: ('f',)
    rg = context.rg_kompetenz_tbl((1,))
    setattr(rg, "komp_meth_%s_t" % parameters[0], value)

def mutter_telefonnummerA_B(value, parameters, context):
    # parameters: (1, 1), (2, 1)
    rg = context.rg_telefon_mutter_tbl(parameters[0])
    rg.mutter_telefonnummer = value

def mutter_vorwahlA_B(value, parameters, context):
    # parameters: (1, 1), (2, 1)
    rg = context.rg_telefon_mutter_tbl(parameters[0])
    rg.mutter_vorwahl = value

def mutter_email_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_telefon_mutter_tbl(parameters[0])
    rg.mutter_email = value 

def mutter_plz_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_mutter_tbl(parameters[0])
    rg.mutter_plz = value

def mutter_ort_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_mutter_tbl(parameters[0])
    rg.mutter_ort = value

def mutter_strasse_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_mutter_tbl(parameters[0])
    rg.mutter_strasse = value

def mutter_strassenr_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_mutter_tbl(parameters[0])
    rg.mutter_strassenr = value

def vater_telefonnummerA_B(value, parameters, context):
    # parameters: (1, 1), (2, 1)
    rg = context.rg_telefon_vater_tbl(parameters[0])
    rg.vater_telefonnummer = value

def vater_vorwahlA_B(value, parameters, context):
    # parameters: (1, 1), (2, 1)
    rg = context.rg_telefon_vater_tbl(parameters[0])
    rg.vater_vorwahl = value

def vater_email_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_telefon_vater_tbl(parameters[0])
    rg.vater_email = value

def vater_plz_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_vater_tbl(parameters[0])
    rg.vater_plz = value

def vater_ort_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_vater_tbl(parameters[0])
    rg.vater_ort = value

def vater_strasse_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_vater_tbl(parameters[0])
    rg.vater_strasse = value

def vater_strassenr_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_vater_tbl(parameters[0])
    rg.vater_strassenr = value

def addresseA_telefonnummer_B(value, parameters, context):
    # parameters: (1, 1), (2, 2)
    rg = context.rg_telefon_betr_person_tbl(parameters[0])
    rg.addresse_telefonnummer = value

def addresseA_vorwahl_B(value, parameters, context):
    # parameters: (1, 1), (2, 1)
    rg = context.rg_telefon_betr_person_tbl(parameters[0])
    rg.addresse_vorwahl = value

def addresse_plz_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_betr_person_tbl(parameters[0])
    rg.addresse_plz = value

def addresse_ort_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_betr_person_tbl(parameters[0])
    rg.addresse_ort = value

def addresse_email_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_betr_person_tbl(parameters[0])
    rg.addresse_email = value

def addresse_strasse_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_betr_person_tbl(parameters[0])
    rg.addresse_strasse = value

def addresse_strassenr_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_adresse_betr_person_tbl(parameters[0])
    rg.addresse_strassenr = value

def addresse_weiteretelefonnummern_A(value, parameters, context):
    # parameters: (1,)
    rg = context.master_tbl(parameters[0])
    rg.addresse_weiteretelefonnummern = value

def bezugs_email_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.inst_person_email = value

def bezugs_vorname_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.inst_person_vorname = value

def bezugs_name_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.inst_person_name = value

def bezugs_telefonnummer_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.inst_person_telefonnummer = value

def bezugs_vorwahl_A(value, parameters, context):
    # parameters: (1,)
    rg = context.rg_institution_tbl(parameters[0] + SCHULE_OFS)
    rg.inst_person_vorwahl = value

def dok_entw(value, parameters, context):
    # parameters: ()
    rg = context.rg_kompetenz_tbl((1,))
    rg.dok_entw = value


# LEAVE THE LOOKUP MAP UNTOUCHED!

LOOKUP = {
    'kd_institution_email_3': lambda v, ctx: kd_institution_email_A(v, (3,), ctx),
    'kd_institution_email_1': lambda v, ctx: kd_institution_email_A(v, (1,), ctx),
    'kd_institution_email_2': lambda v, ctx: kd_institution_email_A(v, (2,), ctx),
    'kd_institution_name_1': lambda v, ctx: kd_institution_name_A(v, (1,), ctx),
    'kd_institution_name_2': lambda v, ctx: kd_institution_name_A(v, (2,), ctx),
    'kd_institution_name_3': lambda v, ctx: kd_institution_name_A(v, (3,), ctx),
    'kd_institution_ort_3': lambda v, ctx: kd_institution_ort_A(v, (3,), ctx),
    'kd_institution_ort_1': lambda v, ctx: kd_institution_ort_A(v, (1,), ctx),
    'kd_institution_ort_2': lambda v, ctx: kd_institution_ort_A(v, (2,), ctx),
    'kd_institution_plz_1': lambda v, ctx: kd_institution_plz_A(v, (1,), ctx),
    'kd_institution_plz_2': lambda v, ctx: kd_institution_plz_A(v, (2,), ctx),
    'kd_institution_plz_3': lambda v, ctx: kd_institution_plz_A(v, (3,), ctx),
    'kd_institution_strasse_3': lambda v, ctx: kd_institution_strasse_A(v, (3,), ctx),
    'kd_institution_strasse_2': lambda v, ctx: kd_institution_strasse_A(v, (2,), ctx),
    'kd_institution_strasse_1': lambda v, ctx: kd_institution_strasse_A(v, (1,), ctx),
    'kd_institution_vorwahl_3': lambda v, ctx: kd_institution_vorwahl_A(v, (3,), ctx),
    'kd_institution_vorwahl_1': lambda v, ctx: kd_institution_vorwahl_A(v, (1,), ctx),
    'kd_institution_vorwahl_2': lambda v, ctx: kd_institution_vorwahl_A(v, (2,), ctx),
    'kd_institution_kundennummer_2': lambda v, ctx: kd_institution_kundennummer_A(v, (2,), ctx),
    'kd_institution_kundennummer_3': lambda v, ctx: kd_institution_kundennummer_A(v, (3,), ctx),
    'kd_institution_kundennummer_1': lambda v, ctx: kd_institution_kundennummer_A(v, (1,), ctx),
    'kd_institution_strassenr_1': lambda v, ctx: kd_institution_strassenr_A(v, (1,), ctx),
    'kd_institution_strassenr_3': lambda v, ctx: kd_institution_strassenr_A(v, (3,), ctx),
    'kd_institution_strassenr_2': lambda v, ctx: kd_institution_strassenr_A(v, (2,), ctx),
    'kd_institution_telefonnummer_1': lambda v, ctx: kd_institution_telefonnummer_A(v, (1,), ctx),
    'kd_institution_telefonnummer_3': lambda v, ctx: kd_institution_telefonnummer_A(v, (3,), ctx),
    'kd_institution_telefonnummer_2': lambda v, ctx: kd_institution_telefonnummer_A(v, (2,), ctx),
    'kd_bezug_email_3': lambda v, ctx: kd_bezug_email_A(v, (3,), ctx),
    'kd_bezug_email_1': lambda v, ctx: kd_bezug_email_A(v, (1,), ctx),
    'kd_bezug_email_2': lambda v, ctx: kd_bezug_email_A(v, (2,), ctx),
    'kd_bezug_strasse_3': lambda v, ctx: kd_bezug_strasse_A(v, (3,), ctx),
    'kd_bezug_strasse_1': lambda v, ctx: kd_bezug_strasse_A(v, (1,), ctx),
    'kd_bezug_strasse_2': lambda v, ctx: kd_bezug_strasse_A(v, (2,), ctx),
    'kd_bezug_plz_3': lambda v, ctx: kd_bezug_plz_A(v, (3,), ctx),
    'kd_bezug_plz_2': lambda v, ctx: kd_bezug_plz_A(v, (2,), ctx),
    'kd_bezug_plz_1': lambda v, ctx: kd_bezug_plz_A(v, (1,), ctx),
    'kd_bezug_strassenr_2': lambda v, ctx: kd_bezug_strassenr_A(v, (2,), ctx),
    'kd_bezug_strassenr_3': lambda v, ctx: kd_bezug_strassenr_A(v, (3,), ctx),
    'kd_bezug_strassenr_1': lambda v, ctx: kd_bezug_strassenr_A(v, (1,), ctx),
    'kd_bezug_ort_1': lambda v, ctx: kd_bezug_ort_A(v, (1,), ctx),
    'kd_bezug_ort_2': lambda v, ctx: kd_bezug_ort_A(v, (2,), ctx),
    'kd_bezug_ort_3': lambda v, ctx: kd_bezug_ort_A(v, (3,), ctx),
    'kd_bezug_vorname_1': lambda v, ctx: kd_bezug_vorname_A(v, (1,), ctx),
    'kd_bezug_vorname_2': lambda v, ctx: kd_bezug_vorname_A(v, (2,), ctx),
    'kd_bezug_vorname_3': lambda v, ctx: kd_bezug_vorname_A(v, (3,), ctx),
    'kd_bezug_name_1': lambda v, ctx: kd_bezug_name_A(v, (1,), ctx),
    'kd_bezug_name_3': lambda v, ctx: kd_bezug_name_A(v, (3,), ctx),
    'kd_bezug_name_2': lambda v, ctx: kd_bezug_name_A(v, (2,), ctx),
    'kd_bezug_funktion_1': lambda v, ctx: kd_bezug_funktion_A(v, (1,), ctx),
    'kd_bezug_funktion_2': lambda v, ctx: kd_bezug_funktion_A(v, (2,), ctx),
    'kd_bezug_funktion_3': lambda v, ctx: kd_bezug_funktion_A(v, (3,), ctx),
    'kd_bezug_3_telefon': lambda v, ctx: kd_bezug_A_telefon(v, (3,), ctx),
    'kd_bezug_1_telefon': lambda v, ctx: kd_bezug_A_telefon(v, (1,), ctx),
    'kd_bezug_2_telefon': lambda v, ctx: kd_bezug_A_telefon(v, (2,), ctx),
    'kd_bezug_3_vorwahl': lambda v, ctx: kd_bezug_A_vorwahl(v, (3,), ctx),
    'kd_bezug_1_vorwahl': lambda v, ctx: kd_bezug_A_vorwahl(v, (1,), ctx),
    'kd_bezug_2_vorwahl': lambda v, ctx: kd_bezug_A_vorwahl(v, (2,), ctx),
    'kd_jugendamt_vorwahl_1': lambda v, ctx: kd_jugendamt_vorwahl_A(v, (1,), ctx),
    'kd_jugendamt_strasse_1': lambda v, ctx: kd_jugendamt_strasse_A(v, (1,), ctx),
    'kd_jugendamt_strassenr_1': lambda v, ctx: kd_jugendamt_strassenr_A(v, (1,), ctx),
    'kd_jugendamt_email_1': lambda v, ctx: kd_jugendamt_email_A(v, (1,), ctx),
    'kd_jugendamt_plz_1': lambda v, ctx: kd_jugendamt_plz_A(v, (1,), ctx),
    'kd_jugendamt_ort_1': lambda v, ctx: kd_jugendamt_ort_A(v, (1,), ctx),
    'kd_jugendamt_kundennummer_1': lambda v, ctx: kd_jugendamt_kundennummer_A(v, (1,), ctx),
    'kd_jugendamt_telefonnummer_1': lambda v, ctx: kd_jugendamt_telefonnummer_A(v, (1,), ctx),
    'kd_schule_vorwahl_1': lambda v, ctx: kd_schule_vorwahl_A(v, (1,), ctx),
    'kd_schule_strasse_1': lambda v, ctx: kd_schule_strasse_A(v, (1,), ctx),
    'kd_schule_strassenr_1': lambda v, ctx: kd_schule_strassenr_A(v, (1,), ctx),
    'kd_schule_email_1': lambda v, ctx: kd_schule_email_A(v, (1,), ctx),
    'kd_schule_plz_1': lambda v, ctx: kd_schule_plz_A(v, (1,), ctx),
    'kd_schule_ort_1': lambda v, ctx: kd_schule_ort_A(v, (1,), ctx),
    'kd_schule_name_1': lambda v, ctx: kd_schule_name_A(v, (1,), ctx),
    'kd_schule_telefonnummer_1': lambda v, ctx: kd_schule_telefonnummer_A(v, (1,), ctx),
    'fehlutg_15': lambda v, ctx: fehlutg_A(v, (15,), ctx),
    'fehlutg_12': lambda v, ctx: fehlutg_A(v, (12,), ctx),
    'fehlutg_7': lambda v, ctx: fehlutg_A(v, (7,), ctx),
    'fehlutg_6': lambda v, ctx: fehlutg_A(v, (6,), ctx),
    'fehlutg_5': lambda v, ctx: fehlutg_A(v, (5,), ctx),
    'fehlutg_4': lambda v, ctx: fehlutg_A(v, (4,), ctx),
    'fehlutg_3': lambda v, ctx: fehlutg_A(v, (3,), ctx),
    'fehlutg_2': lambda v, ctx: fehlutg_A(v, (2,), ctx),
    'fehlutg_1': lambda v, ctx: fehlutg_A(v, (1,), ctx),
    'fehlutg_18': lambda v, ctx: fehlutg_A(v, (18,), ctx),
    'fehlutg_17': lambda v, ctx: fehlutg_A(v, (17,), ctx),
    'fehlutg_16': lambda v, ctx: fehlutg_A(v, (16,), ctx),
    'fehlutg_14': lambda v, ctx: fehlutg_A(v, (14,), ctx),
    'fehlutg_13': lambda v, ctx: fehlutg_A(v, (13,), ctx),
    'fehlutg_11': lambda v, ctx: fehlutg_A(v, (11,), ctx),
    'fehlutg_10': lambda v, ctx: fehlutg_A(v, (10,), ctx),
    'fehlutg_9': lambda v, ctx: fehlutg_A(v, (9,), ctx),
    'fehlutg_8': lambda v, ctx: fehlutg_A(v, (8,), ctx),
    'fehlm_8': lambda v, ctx: fehlA_B(v, ('m', 8), ctx),
    'fehlj_1': lambda v, ctx: fehlA_B(v, ('j', 1), ctx),
    'fehlj_10': lambda v, ctx: fehlA_B(v, ('j', 10), ctx),
    'fehlm_18': lambda v, ctx: fehlA_B(v, ('m', 18), ctx),
    'fehlm_10': lambda v, ctx: fehlA_B(v, ('m', 10), ctx),
    'fehlm_11': lambda v, ctx: fehlA_B(v, ('m', 11), ctx),
    'fehlm_13': lambda v, ctx: fehlA_B(v, ('m', 13), ctx),
    'fehlm_14': lambda v, ctx: fehlA_B(v, ('m', 14), ctx),
    'fehlm_15': lambda v, ctx: fehlA_B(v, ('m', 15), ctx),
    'fehlm_16': lambda v, ctx: fehlA_B(v, ('m', 16), ctx),
    'fehlm_17': lambda v, ctx: fehlA_B(v, ('m', 17), ctx),
    'fehlj_15': lambda v, ctx: fehlA_B(v, ('j', 15), ctx),
    'fehlm_6': lambda v, ctx: fehlA_B(v, ('m', 6), ctx),
    'fehlm_4': lambda v, ctx: fehlA_B(v, ('m', 4), ctx),
    'fehlm_5': lambda v, ctx: fehlA_B(v, ('m', 5), ctx),
    'fehlm_3': lambda v, ctx: fehlA_B(v, ('m', 3), ctx),
    'fehlm_9': lambda v, ctx: fehlA_B(v, ('m', 9), ctx),
    'fehlj_18': lambda v, ctx: fehlA_B(v, ('j', 18), ctx),
    'fehlj_11': lambda v, ctx: fehlA_B(v, ('j', 11), ctx),
    'fehlj_13': lambda v, ctx: fehlA_B(v, ('j', 13), ctx),
    'fehlj_12': lambda v, ctx: fehlA_B(v, ('j', 12), ctx),
    'fehlj_14': lambda v, ctx: fehlA_B(v, ('j', 14), ctx),
    'fehlj_17': lambda v, ctx: fehlA_B(v, ('j', 17), ctx),
    'fehlj_16': lambda v, ctx: fehlA_B(v, ('j', 16), ctx),
    'fehlm_1': lambda v, ctx: fehlA_B(v, ('m', 1), ctx),
    'fehlm_2': lambda v, ctx: fehlA_B(v, ('m', 2), ctx),
    'fehlm_7': lambda v, ctx: fehlA_B(v, ('m', 7), ctx),
    'fehlj_9': lambda v, ctx: fehlA_B(v, ('j', 9), ctx),
    'fehlj_8': lambda v, ctx: fehlA_B(v, ('j', 8), ctx),
    'fehlj_5': lambda v, ctx: fehlA_B(v, ('j', 5), ctx),
    'fehlj_4': lambda v, ctx: fehlA_B(v, ('j', 4), ctx),
    'fehlj_7': lambda v, ctx: fehlA_B(v, ('j', 7), ctx),
    'fehlj_3': lambda v, ctx: fehlA_B(v, ('j', 3), ctx),
    'fehlj_2': lambda v, ctx: fehlA_B(v, ('j', 2), ctx),
    'fehlm_12': lambda v, ctx: fehlA_B(v, ('m', 12), ctx),
    'fehlj_6': lambda v, ctx: fehlA_B(v, ('j', 6), ctx),
    'fehltg_14': lambda v, ctx: fehltg_A(v, (14,), ctx),
    'fehltg_7': lambda v, ctx: fehltg_A(v, (7,), ctx),
    'fehltg_15': lambda v, ctx: fehltg_A(v, (15,), ctx),
    'fehltg_17': lambda v, ctx: fehltg_A(v, (17,), ctx),
    'fehltg_16': lambda v, ctx: fehltg_A(v, (16,), ctx),
    'fehltg_11': lambda v, ctx: fehltg_A(v, (11,), ctx),
    'fehltg_10': lambda v, ctx: fehltg_A(v, (10,), ctx),
    'fehltg_13': lambda v, ctx: fehltg_A(v, (13,), ctx),
    'fehltg_12': lambda v, ctx: fehltg_A(v, (12,), ctx),
    'fehltg_18': lambda v, ctx: fehltg_A(v, (18,), ctx),
    'fehltg_9': lambda v, ctx: fehltg_A(v, (9,), ctx),
    'fehltg_8': lambda v, ctx: fehltg_A(v, (8,), ctx),
    'fehltg_5': lambda v, ctx: fehltg_A(v, (5,), ctx),
    'fehltg_4': lambda v, ctx: fehltg_A(v, (4,), ctx),
    'fehltg_6': lambda v, ctx: fehltg_A(v, (6,), ctx),
    'fehltg_1': lambda v, ctx: fehltg_A(v, (1,), ctx),
    'fehltg_2': lambda v, ctx: fehltg_A(v, (2,), ctx),
    'fehltg_3': lambda v, ctx: fehltg_A(v, (3,), ctx),
    'fehlfust_10': lambda v, ctx: fehlfust_A(v, (10,), ctx),
    'fehlfust_11': lambda v, ctx: fehlfust_A(v, (11,), ctx),
    'fehlfust_12': lambda v, ctx: fehlfust_A(v, (12,), ctx),
    'fehlfust_14': lambda v, ctx: fehlfust_A(v, (14,), ctx),
    'fehlfust_3': lambda v, ctx: fehlfust_A(v, (3,), ctx),
    'fehlfust_2': lambda v, ctx: fehlfust_A(v, (2,), ctx),
    'fehlfust_6': lambda v, ctx: fehlfust_A(v, (6,), ctx),
    'fehlfust_5': lambda v, ctx: fehlfust_A(v, (5,), ctx),
    'fehlfust_8': lambda v, ctx: fehlfust_A(v, (8,), ctx),
    'fehlfust_15': lambda v, ctx: fehlfust_A(v, (15,), ctx),
    'fehlfust_16': lambda v, ctx: fehlfust_A(v, (16,), ctx),
    'fehlfust_17': lambda v, ctx: fehlfust_A(v, (17,), ctx),
    'fehlfust_18': lambda v, ctx: fehlfust_A(v, (18,), ctx),
    'fehlfust_9': lambda v, ctx: fehlfust_A(v, (9,), ctx),
    'fehlfust_1': lambda v, ctx: fehlfust_A(v, (1,), ctx),
    'fehlfust_7': lambda v, ctx: fehlfust_A(v, (7,), ctx),
    'fehlfust_4': lambda v, ctx: fehlfust_A(v, (4,), ctx),
    'fehlfust_13': lambda v, ctx: fehlfust_A(v, (13,), ctx),
    'fehlst_17': lambda v, ctx: fehlst_A(v, (17,), ctx),
    'fehlst_11': lambda v, ctx: fehlst_A(v, (11,), ctx),
    'fehlst_18': lambda v, ctx: fehlst_A(v, (18,), ctx),
    'fehlst_10': lambda v, ctx: fehlst_A(v, (10,), ctx),
    'fehlst_1': lambda v, ctx: fehlst_A(v, (1,), ctx),
    'fehlst_7': lambda v, ctx: fehlst_A(v, (7,), ctx),
    'fehlst_6': lambda v, ctx: fehlst_A(v, (6,), ctx),
    'fehlst_5': lambda v, ctx: fehlst_A(v, (5,), ctx),
    'fehlst_14': lambda v, ctx: fehlst_A(v, (14,), ctx),
    'fehlst_16': lambda v, ctx: fehlst_A(v, (16,), ctx),
    'fehlst_15': lambda v, ctx: fehlst_A(v, (15,), ctx),
    'fehlst_3': lambda v, ctx: fehlst_A(v, (3,), ctx),
    'fehlst_2': lambda v, ctx: fehlst_A(v, (2,), ctx),
    'fehlst_4': lambda v, ctx: fehlst_A(v, (4,), ctx),
    'fehlst_13': lambda v, ctx: fehlst_A(v, (13,), ctx),
    'fehlst_12': lambda v, ctx: fehlst_A(v, (12,), ctx),
    'fehlst_9': lambda v, ctx: fehlst_A(v, (9,), ctx),
    'fehlst_8': lambda v, ctx: fehlst_A(v, (8,), ctx),
    'entw_beh': lambda v, ctx: entw_beh(v, (), ctx),
    'entw_b_1': lambda v, ctx: entw_A_B(v, ('b', 1), ctx),
    'entw_f_1': lambda v, ctx: entw_A_B(v, ('f', 1), ctx),
    'entw_k_1': lambda v, ctx: entw_A_B(v, ('k', 1), ctx),
    'entw_j_1': lambda v, ctx: entw_A_B(v, ('j', 1), ctx),
    'entw_a_1': lambda v, ctx: entw_A_B(v, ('a', 1), ctx),
    'entw_g_1': lambda v, ctx: entw_A_B(v, ('g', 1), ctx),
    'entw_e_1': lambda v, ctx: entw_A_B(v, ('e', 1), ctx),
    'entw_d_1': lambda v, ctx: entw_A_B(v, ('d', 1), ctx),
    'entw_c_1': lambda v, ctx: entw_A_B(v, ('c', 1), ctx),
    'entw_i_1': lambda v, ctx: entw_A_B(v, ('i', 1), ctx),
    'entw_h_1': lambda v, ctx: entw_A_B(v, ('h', 1), ctx),
    'entw_k_t_1': lambda v, ctx: entw_A_t_B(v, ('k', 1), ctx),
    'entw_h_t_1': lambda v, ctx: entw_A_t_B(v, ('h', 1), ctx),
    'entw_i_t_1': lambda v, ctx: entw_A_t_B(v, ('i', 1), ctx),
    'entw_j_t_1': lambda v, ctx: entw_A_t_B(v, ('j', 1), ctx),
    'hilfm_1': lambda v, ctx: hilfm_A(v, (1,), ctx),
    'hilfm_2': lambda v, ctx: hilfm_A(v, (2,), ctx),
    'hilfm_3': lambda v, ctx: hilfm_A(v, (3,), ctx),
    'hilfm_ende_2': lambda v, ctx: hilfm_ende_A(v, (2,), ctx),
    'hilfm_ende_3': lambda v, ctx: hilfm_ende_A(v, (3,), ctx),
    'hilfm_ende_1': lambda v, ctx: hilfm_ende_A(v, (1,), ctx),
    'hilfm_start_1': lambda v, ctx: hilfm_start_A(v, (1,), ctx),
    'hilfm_start_3': lambda v, ctx: hilfm_start_A(v, (3,), ctx),
    'hilfm_start_2': lambda v, ctx: hilfm_start_A(v, (2,), ctx),
    'hilfm_sf_3': lambda v, ctx: hilfm_sf_A(v, (3,), ctx),
    'hilfm_sf_2': lambda v, ctx: hilfm_sf_A(v, (2,), ctx),
    'hilfm_sf_1': lambda v, ctx: hilfm_sf_A(v, (1,), ctx),
    'hilfm_umf_3': lambda v, ctx: hilfm_umf_A(v, (3,), ctx),
    'hilfm_umf_2': lambda v, ctx: hilfm_umf_A(v, (2,), ctx),
    'hilfm_umf_1': lambda v, ctx: hilfm_umf_A(v, (1,), ctx),
    'hilfm_erreicht_3_2': lambda v, ctx: hilfm_erreicht_A_B(v, (3, 2), ctx),
    'hilfm_erreicht_1_1': lambda v, ctx: hilfm_erreicht_A_B(v, (1, 1), ctx),
    'hilfm_erreicht_1_2': lambda v, ctx: hilfm_erreicht_A_B(v, (1, 2), ctx),
    'hilfm_erreicht_3_1': lambda v, ctx: hilfm_erreicht_A_B(v, (3, 1), ctx),
    'hilfm_erreicht_2_1': lambda v, ctx: hilfm_erreicht_A_B(v, (2, 1), ctx),
    'hilfm_erreicht_2_3': lambda v, ctx: hilfm_erreicht_A_B(v, (2, 3), ctx),
    'hilfm_erreicht_3_3': lambda v, ctx: hilfm_erreicht_A_B(v, (3, 3), ctx),
    'hilfm_erreicht_2_2': lambda v, ctx: hilfm_erreicht_A_B(v, (2, 2), ctx),
    'hilfm_erreicht_1_3': lambda v, ctx: hilfm_erreicht_A_B(v, (1, 3), ctx),
    'hilfm_ziel_1_1': lambda v, ctx: hilfm_ziel_A_B(v, (1, 1), ctx),
    'hilfm_ziel_1_2': lambda v, ctx: hilfm_ziel_A_B(v, (1, 2), ctx),
    'hilfm_ziel_1_3': lambda v, ctx: hilfm_ziel_A_B(v, (1, 3), ctx),
    'hilfm_ziel_3_1': lambda v, ctx: hilfm_ziel_A_B(v, (3, 1), ctx),
    'hilfm_ziel_2_3': lambda v, ctx: hilfm_ziel_A_B(v, (2, 3), ctx),
    'hilfm_ziel_2_2': lambda v, ctx: hilfm_ziel_A_B(v, (2, 2), ctx),
    'hilfm_ziel_2_1': lambda v, ctx: hilfm_ziel_A_B(v, (2, 1), ctx),
    'hilfm_ziel_3_2': lambda v, ctx: hilfm_ziel_A_B(v, (3, 2), ctx),
    'hilfm_ziel_3_3': lambda v, ctx: hilfm_ziel_A_B(v, (3, 3), ctx),
    'hilfm_inst_2': lambda v, ctx: hilfm_inst_A(v, (2,), ctx),
    'hilfm_inst_3': lambda v, ctx: hilfm_inst_A(v, (3,), ctx),
    'hilfm_inst_1': lambda v, ctx: hilfm_inst_A(v, (1,), ctx),
    'hilfm_zeit_2_2': lambda v, ctx: hilfm_zeit_A_B(v, (2, 2), ctx),
    'hilfm_zeit_2_1': lambda v, ctx: hilfm_zeit_A_B(v, (2, 1), ctx),
    'hilfm_zeit_2_3': lambda v, ctx: hilfm_zeit_A_B(v, (2, 3), ctx),
    'hilfm_zeit_3_2': lambda v, ctx: hilfm_zeit_A_B(v, (3, 2), ctx),
    'hilfm_zeit_1_1': lambda v, ctx: hilfm_zeit_A_B(v, (1, 1), ctx),
    'hilfm_zeit_1_2': lambda v, ctx: hilfm_zeit_A_B(v, (1, 2), ctx),
    'hilfm_zeit_1_3': lambda v, ctx: hilfm_zeit_A_B(v, (1, 3), ctx),
    'hilfm_zeit_3_3': lambda v, ctx: hilfm_zeit_A_B(v, (3, 3), ctx),
    'hilfm_zeit_3_1': lambda v, ctx: hilfm_zeit_A_B(v, (3, 1), ctx),
    'hilfm_art_3': lambda v, ctx: hilfm_art_A(v, (3,), ctx),
    'hilfm_art_1': lambda v, ctx: hilfm_art_A(v, (1,), ctx),
    'hilfm_art_2': lambda v, ctx: hilfm_art_A(v, (2,), ctx),
    'hilfm_einr_1': lambda v, ctx: hilfm_einr_A(v, (1,), ctx),
    'hilfm_einr_2': lambda v, ctx: hilfm_einr_A(v, (2,), ctx),
    'hilfm_einr_3': lambda v, ctx: hilfm_einr_A(v, (3,), ctx),
    'komp_schule_c_1': lambda v, ctx: komp_schule_A_B(v, ('c', 1), ctx),
    'komp_schule_g_1': lambda v, ctx: komp_schule_A_B(v, ('g', 1), ctx),
    'komp_schule_e_1': lambda v, ctx: komp_schule_A_B(v, ('e', 1), ctx),
    'komp_schule_f_1': lambda v, ctx: komp_schule_A_B(v, ('f', 1), ctx),
    'komp_schule_d_1': lambda v, ctx: komp_schule_A_B(v, ('d', 1), ctx),
    'komp_schule_a_1': lambda v, ctx: komp_schule_A_B(v, ('a', 1), ctx),
    'komp_schule_b_1': lambda v, ctx: komp_schule_A_B(v, ('b', 1), ctx),
    'komp_sozial_b_1': lambda v, ctx: komp_sozial_A_B(v, ('b', 1), ctx),
    'komp_sozial_f_1': lambda v, ctx: komp_sozial_A_B(v, ('f', 1), ctx),
    'komp_sozial_d_1': lambda v, ctx: komp_sozial_A_B(v, ('d', 1), ctx),
    'komp_sozial_c_1': lambda v, ctx: komp_sozial_A_B(v, ('c', 1), ctx),
    'komp_sozial_e_1': lambda v, ctx: komp_sozial_A_B(v, ('e', 1), ctx),
    'komp_sozial_g_1': lambda v, ctx: komp_sozial_A_B(v, ('g', 1), ctx),
    'komp_sozial_a_1': lambda v, ctx: komp_sozial_A_B(v, ('a', 1), ctx),
    'komp_deutsch_b_1': lambda v, ctx: komp_deutsch_A_B(v, ('b', 1), ctx),
    'komp_deutsch_d_1': lambda v, ctx: komp_deutsch_A_B(v, ('d', 1), ctx),
    'komp_deutsch_c_1': lambda v, ctx: komp_deutsch_A_B(v, ('c', 1), ctx),
    'komp_deutsch_a_1': lambda v, ctx: komp_deutsch_A_B(v, ('a', 1), ctx),
    'komp_selbst_e_1': lambda v, ctx: komp_selbst_A_B(v, ('e', 1), ctx),
    'komp_selbst_b_1': lambda v, ctx: komp_selbst_A_B(v, ('b', 1), ctx),
    'komp_selbst_f_1': lambda v, ctx: komp_selbst_A_B(v, ('f', 1), ctx),
    'komp_selbst_d_1': lambda v, ctx: komp_selbst_A_B(v, ('d', 1), ctx),
    'komp_selbst_c_1': lambda v, ctx: komp_selbst_A_B(v, ('c', 1), ctx),
    'komp_selbst_a_1': lambda v, ctx: komp_selbst_A_B(v, ('a', 1), ctx),
    'komp_selbst_g_1': lambda v, ctx: komp_selbst_A_B(v, ('g', 1), ctx),
    'komp_psy_c_1': lambda v, ctx: komp_psy_A_B(v, ('c', 1), ctx),
    'komp_psy_a_1': lambda v, ctx: komp_psy_A_B(v, ('a', 1), ctx),
    'komp_psy_g_1': lambda v, ctx: komp_psy_A_B(v, ('g', 1), ctx),
    'komp_psy_e_1': lambda v, ctx: komp_psy_A_B(v, ('e', 1), ctx),
    'komp_psy_d_1': lambda v, ctx: komp_psy_A_B(v, ('d', 1), ctx),
    'komp_psy_f_1': lambda v, ctx: komp_psy_A_B(v, ('f', 1), ctx),
    'komp_psy_b_1': lambda v, ctx: komp_psy_A_B(v, ('b', 1), ctx),
    'komp_herkunft_1': lambda v, ctx: komp_herkunft_A(v, (1,), ctx),
    'komp_selbst_g_t_1': lambda v, ctx: komp_X_g_t_1(v, ('selbst',), ctx),
    'komp_schule_g_t_1': lambda v, ctx: komp_X_g_t_1(v, ('schule',), ctx),
    'komp_sozial_g_t_1': lambda v, ctx: komp_X_g_t_1(v, ('sozial',), ctx),
    'komp_psy_g_t_1': lambda v, ctx: komp_X_g_t_1(v, ('psy',), ctx),
    'komp_anm': lambda v, ctx: komp_anm(v, (), ctx),
    'datum_kf_1': lambda v, ctx: datum_kf_A(v, (1,), ctx),
    'kf_anbiet_1': lambda v, ctx: kf_anbiet_A(v, (1,), ctx),
    'kf_verfahren_1': lambda v, ctx: kf_verfahren_A(v, (1,), ctx),
    'kf_meth_d_1': lambda v, ctx: kf_meth_A_1(v, ('d',), ctx),
    'kf_meth_f_1': lambda v, ctx: kf_meth_A_1(v, ('f',), ctx),
    'kf_meth_b_1': lambda v, ctx: kf_meth_A_1(v, ('b',), ctx),
    'kf_meth_e_1': lambda v, ctx: kf_meth_A_1(v, ('e',), ctx),
    'kf_meth_a_1': lambda v, ctx: kf_meth_A_1(v, ('a',), ctx),
    'kf_test_a_1': lambda v, ctx: kf_test_A_1(v, ('a',), ctx),
    'kf_test_b_1': lambda v, ctx: kf_test_A_1(v, ('b',), ctx),
    'kf_test_d_1': lambda v, ctx: kf_test_A_1(v, ('d',), ctx),
    'kf_test_c_1': lambda v, ctx: kf_test_A_1(v, ('c',), ctx),
    'kf_test_d_t_1': lambda v, ctx: kf_test_A_t_1(v, ('d',), ctx),
    'kf_test_a_t_1': lambda v, ctx: kf_test_A_t_1(v, ('a',), ctx),
    'kf_test_b_t_1': lambda v, ctx: kf_test_A_t_1(v, ('b',), ctx),
    'kf_test_c_t_1': lambda v, ctx: kf_test_A_t_1(v, ('c',), ctx),
    'kf_meth_f_t_1': lambda v, ctx: kf_meth_A_t_1(v, ('f',), ctx),
    'mutter_telefonnummer2_1': lambda v, ctx: mutter_telefonnummerA_B(v, (2, 1), ctx),
    'mutter_telefonnummer1_1': lambda v, ctx: mutter_telefonnummerA_B(v, (1, 1), ctx),
    'mutter_vorwahl1_1': lambda v, ctx: mutter_vorwahlA_B(v, (1, 1), ctx),
    'mutter_vorwahl2_1': lambda v, ctx: mutter_vorwahlA_B(v, (2, 1), ctx),
    'mutter_email_1': lambda v, ctx: mutter_email_A(v, (1,), ctx),
    'mutter_plz_1': lambda v, ctx: mutter_plz_A(v, (1,), ctx),
    'mutter_ort_1': lambda v, ctx: mutter_ort_A(v, (1,), ctx),
    'mutter_strasse_1': lambda v, ctx: mutter_strasse_A(v, (1,), ctx),
    'mutter_strassenr_1': lambda v, ctx: mutter_strassenr_A(v, (1,), ctx),
    'vater_telefonnummer2_1': lambda v, ctx: vater_telefonnummerA_B(v, (2, 1), ctx),
    'vater_telefonnummer1_1': lambda v, ctx: vater_telefonnummerA_B(v, (1, 1), ctx),
    'vater_vorwahl1_1': lambda v, ctx: vater_vorwahlA_B(v, (1, 1), ctx),
    'vater_vorwahl2_1': lambda v, ctx: vater_vorwahlA_B(v, (2, 1), ctx),
    'vater_email_1': lambda v, ctx: vater_email_A(v, (1,), ctx),
    'vater_plz_1': lambda v, ctx: vater_plz_A(v, (1,), ctx),
    'vater_ort_1': lambda v, ctx: vater_ort_A(v, (1,), ctx),
    'vater_strasse_1': lambda v, ctx: vater_strasse_A(v, (1,), ctx),
    'vater_strassenr_1': lambda v, ctx: vater_strassenr_A(v, (1,), ctx),
    'addresse2_telefonnummer_2': lambda v, ctx: addresseA_telefonnummer_B(v, (2, 2), ctx),
    'addresse1_telefonnummer_1': lambda v, ctx: addresseA_telefonnummer_B(v, (1, 1), ctx),
    'addresse1_vorwahl_1': lambda v, ctx: addresseA_vorwahl_B(v, (1, 1), ctx),
    'addresse2_vorwahl_1': lambda v, ctx: addresseA_vorwahl_B(v, (2, 1), ctx),
    'addresse_plz_1': lambda v, ctx: addresse_plz_A(v, (1,), ctx),
    'addresse_ort_1': lambda v, ctx: addresse_ort_A(v, (1,), ctx),
    'addresse_email_1': lambda v, ctx: addresse_email_A(v, (1,), ctx),
    'addresse_strasse_1': lambda v, ctx: addresse_strasse_A(v, (1,), ctx),
    'addresse_strassenr_1': lambda v, ctx: addresse_strassenr_A(v, (1,), ctx),
    'addresse_weiteretelefonnummern_1': lambda v, ctx: addresse_weiteretelefonnummern_A(v, (1,), ctx),
    'bezugs_email_1': lambda v, ctx: bezugs_email_A(v, (1,), ctx),
    'bezugs_vorname_1': lambda v, ctx: bezugs_vorname_A(v, (1,), ctx),
    'bezugs_name_1': lambda v, ctx: bezugs_name_A(v, (1,), ctx),
    'bezugs_telefonnummer_1': lambda v, ctx: bezugs_telefonnummer_A(v, (1,), ctx),
    'bezugs_vorwahl_1': lambda v, ctx: bezugs_vorwahl_A(v, (1,), ctx),
    'dok_entw': lambda v, ctx: dok_entw(v, (), ctx)
}
    

# FIELDS ONLY IN NEW: 2

ONLY_IN_NEW = set([
    "addresse_weiteretelefonnummern",
    "dok_nbetr"])

# FIELDS TO BE COPIED THROUGH: 352

COPY_THRU = set([
    "abschl_gef",
    "abschl_pr",
    "bearbeiter_id",
    "beschul_a",
    "beschul_b",
    "beschul_c",
    "beschul_d",
    "beschul_e",
    "beschul_end_a",
    "beschul_end_b",
    "beschul_end_c",
    "beschul_end_d",
    "beschul_end_e",
    "beschul_end_f",
    "beschul_end_h",
    "beschul_end_h_t",
    "beschul_f",
    "beschul_h",
    "beschul_h_t",
    "bezugsperson_a",
    "bezugsperson_b",
    "bezugsperson_c",
    "bezugsperson_d",
    "bezugsperson_e",
    "bezugsperson_f",
    "bezugsperson_g",
    "bezugsperson_h",
    "bezugsperson_i",
    "bezugsperson_j",
    "bezugsperson_k",
    "bezugsperson_l",
    "bezugsperson_m",
    "bezugsperson_n",
    "bezugsperson_o",
    "bezugsperson_p",
    "bezugsperson_q",
    "bezugsperson_r",
    "bezugsperson_r_t",
    "cm2c",
    "cm2c_t",
    "cm_anmerk_verlaengerung_1",
    "cm_anmerk_verlaengerung_2",
    "cm_bestaet_verlaengerung_1",
    "cm_bestaet_verlaengerung_2",
    "cm_datum_verlaengerung_1",
    "cm_datum_verlaengerung_2",
    "cm_dok_datum_beendigung",
    "cm_dok_end_art",
    "cm_dok_end_sonst",
    "cm_dok_end_verm",
    "cm_end_ab",
    "cm_end_abgr",
    "cm_end_abgr_t",
    "cm_end_art",
    "cm_end_jg",
    "cm_end_schul",
    "cm_end_schul_t",
    "cm_end_sonst",
    "cm_end_sonst_t",
    "cm_end_verm",
    "cm_end_verm_t",
    "cm_kontakt",
    "cm_kontakt_sonstige",
    "cm_kontakt_sonstige_t",
    "cm_neuauf_genehm",
    "cm_schulbes_1",
    "cm_schulbes_2",
    "cm_schule_name",
    "cm_schule_ort",
    "cm_schule_person_1",
    "cm_schule_person_2",
    "cm_schule_plz",
    "cm_schule_strasse",
    "cm_schule_strassenr",
    "cm_wiederauf_datum_bis_1",
    "cm_wiederauf_datum_bis_2",
    "cm_wiederauf_genehm_1",
    "cm_wiederauf_genehm_2",
    "cm_wiederauf_genehm_datum_1",
    "cm_zeit",
    "cm_ziel",
    "cm_zielsch_a",
    "cm_zielsch_b",
    "cm_zielsch_c",
    "cm_zielsch_d",
    "cm_zielsch_e",
    "cm_zielsch_f",
    "cm_zielsch_g",
    "cm_zielsch_h",
    "cm_zielsch_h_t",
    "cm_zielsoz_a",
    "cm_zielsoz_b",
    "cm_zielsoz_c",
    "cm_zielsoz_d",
    "cm_zielsoz_e",
    "cm_zielsoz_f",
    "cm_zielsoz_g",
    "cm_zielsoz_h",
    "cm_zielsoz_h_t",
    "datum_bfplan",
    "datum_cm_ende",
    "datum_cm_start",
    "dok_abschl",
    "dok_angaben",
    "dok_biograf",
    "dok_cm",
    "dok_eingang",
    "dok_ziel",
    "einkommen_a",
    "einkommen_b",
    "einkommen_c",
    "einkommen_d",
    "einkommen_d_t",
    "einkommen_e",
    "einwilligung",
    "ekomp_a",
    "ekomp_b",
    "ekomp_c",
    "ekomp_d",
    "ekomp_e",
    "ekomp_f",
    "ekomp_g",
    "ekomp_h",
    "ekomp_i",
    "ekomp_i_t",
    "elt_koop",
    "elt_mn_a",
    "elt_mn_b",
    "elt_mn_c",
    "elt_mn_d",
    "elt_mn_e",
    "elt_mn_f",
    "elt_mn_g",
    "elt_mn_h",
    "elt_mn_i",
    "elt_mn_j",
    "elt_mn_j_t",
    "elt_sf_a",
    "elt_sf_b",
    "elt_sf_c",
    "elt_sf_d",
    "elt_sf_e",
    "elt_sf_f",
    "elt_sf_g",
    "elt_sf_h",
    "elt_sf_i",
    "elt_zerr_a",
    "elt_zerr_b",
    "elt_zerr_c",
    "elt_zerr_d",
    "elt_zerr_e",
    "elt_zerr_f",
    "elt_zerr_g",
    "elt_zerr_h",
    "elt_zerr_i",
    "elt_ziel_a",
    "elt_ziel_b",
    "elt_ziel_c",
    "elt_ziel_d",
    "elt_ziel_e",
    "elt_ziel_f",
    "elt_ziel_g",
    "elt_ziel_h",
    "elt_ziel_i",
    "elt_ziel_i_t",
    "erstgespraech",
    "familie_anm",
    "fehlst_m",
    "fehlst_m_ue",
    "fehlst_sj",
    "fehlst_sj_ue",
    "fehltg_m",
    "fehltg_m_ue",
    "fehltg_sj",
    "fehltg_sj_ue",
    "fkz",
    "fn",
    "geburtsdatum",
    "geschlecht",
    "geschw_alt_a",
    "geschw_alt_b",
    "geschw_alt_c",
    "geschw_alt_d",
    "geschw_hh",
    "geschw_m",
    "geschw_vorhanden",
    "geschw_w",
    "hilfm_weitere",
    "id",
    "kinder",
    "kinder_allein",
    "kinder_hh",
    "klassenstufe",
    "klassenwdh",
    "kontakt",
    "ks",
    "leistung_d",
    "leistung_fs",
    "leistung_ges",
    "leistung_m",
    "mitarb_vn",
    "mitarb_vv",
    "mitarb_zn",
    "mitarb_zv",
    "mutter",
    "mutter_beruf",
    "mutter_bildung",
    "mutter_bildung_t",
    "mutter_gb",
    "mutter_land",
    "mutter_land_t",
    "mutter_n",
    "mutter_sonst",
    "mutter_spra",
    "mutter_staat",
    "mutter_vn",
    "name",
    "nat_haspra",
    "nat_land",
    "nat_land_t",
    "nat_muspra",
    "nat_muspra_t",
    "nat_staat",
    "nat_status",
    "nat_wohn",
    "nbetr_ende",
    "nbetr_mn",
    "nbetr_start",
    "nbetr_verbl",
    "nbetr_verbl_t",
    "nbtr",
    "ordmn",
    "phase",
    "probleme_a",
    "probleme_b",
    "probleme_c",
    "probleme_d",
    "probleme_e",
    "probleme_f",
    "probleme_f_t",
    "problfam_a",
    "problfam_b",
    "problfam_c",
    "problfam_d",
    "problfam_e",
    "problfam_f",
    "problfam_g",
    "problfam_h",
    "problfam_i",
    "problfam_j",
    "problfam_k",
    "problfam_l",
    "problfam_m",
    "problfam_m_t",
    "psorge",
    "psorge_t",
    "reint_beding_a",
    "reint_beding_b",
    "reint_beding_c",
    "reint_beding_d",
    "reint_beding_d_t",
    "reint_ziel",
    "reint_ziel_t",
    "schulform",
    "schulform_t",
    "sinteresse_a",
    "sinteresse_b",
    "sv_a",
    "sv_aktiv",
    "sv_b",
    "sv_c",
    "sv_d",
    "sv_e",
    "sv_f",
    "sv_g",
    "sv_g_t",
    "sv_monate",
    "sv_passiv",
    "uleistung_anm",
    "uleistung_beginn",
    "uleistung_beginn_a",
    "uleistung_beginn_b",
    "uleistung_beginn_c",
    "uleistung_beginn_d",
    "uleistung_beginn_e",
    "uleistung_beginn_f",
    "uleistung_beginn_g",
    "uleistung_beginn_h",
    "uleistung_beginn_i",
    "uleistung_beginn_j",
    "uleistung_beginn_j_t",
    "uleistung_ende",
    "uleistung_ende_a",
    "uleistung_ende_b",
    "uleistung_ende_c",
    "uleistung_ende_d",
    "uleistung_ende_e",
    "uleistung_ende_f",
    "uleistung_ende_g",
    "uleistung_ende_h",
    "uleistung_ende_i",
    "uleistung_ende_j",
    "uleistung_ende_j_t",
    "uleistung_verg",
    "uuid_id",
    "vater",
    "vater_beruf",
    "vater_bildung",
    "vater_bildung_t",
    "vater_gb",
    "vater_land",
    "vater_land_t",
    "vater_n",
    "vater_sonst",
    "vater_spra",
    "vater_staat",
    "vater_vn",
    "vereinb_a",
    "vereinb_b",
    "vereinb_c",
    "vereinb_d",
    "vereinb_e",
    "vereinb_f",
    "vereinb_f_t",
    "vorname",
    "wohnauf",
    "wohnauf_t",
    "wohnort",
    "zielcm_schul_a",
    "zielcm_schul_b",
    "zielcm_schul_c",
    "zielcm_schul_d",
    "zielcm_schul_e",
    "zielcm_schul_f",
    "zielcm_schul_g",
    "zielcm_schul_h",
    "zielcm_schul_h_t",
    "zielcm_sozial_a",
    "zielcm_sozial_b",
    "zielcm_sozial_c",
    "zielcm_sozial_d",
    "zielcm_sozial_e",
    "zielcm_sozial_f",
    "zielcm_sozial_g",
    "zielcm_sozial_h",
    "zielcm_sozial_h_t",
    "zugang",
    "zugang_t",
    "zugeh_a",
    "zugeh_b",
    "zugeh_c",
    "zugeh_d"])

# not mapped: 0
# default mapped: 0
