BEGIN;

-- 
-- Repeat Group fuer Hilfsmassnahmen
-- 

ALTER TABLE master_tbl DISABLE TRIGGER USER;


SET ROLE :db_adm;

INSERT INTO db_history (beschreibung, zeitpunkt)
       VALUES ('2.0/05_rg_hilfsmassnahmen.sql', current_timestamp);


-- Create a new function to generate RG-entries.
-- This is the original function, without the DS IS check and exception
CREATE OR REPLACE FUNCTION create_rg_hilfsmassnahmen_tbl(pid integer, nuuid char(36))
RETURNS integer
LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER AS
$$
DECLARE
    rid integer;
    mid integer;
BEGIN
    mid := pid;

    IF NOT isEditorOrStandin(mid) THEN
        -- RAISE EXCEPTION 'DS ID not session_user ID';
    END IF;

    INSERT INTO rg_hilfsmassnahmen_tbl (master_id) VALUES (pid);

    SELECT INTO rid currval('rg_hilfsmassnahmen_tbl_id_seq');

    IF nuuid IS NOT NULL THEN
        UPDATE rg_hilfsmassnahmen_tbl
        SET    uuid_id = nuuid
        WHERE  id = rid;
    ELSE
        PERFORM set_uuid('rg_hilfsmassnahmen_tbl', rid);
        
    END IF;

    RETURN rid;
END;
$$;


-- Uebernahme der alten Eintraege in eine Repeat Group
--
-- Fuer alle Eintrage in der master_tbl
CREATE OR REPLACE FUNCTION insert_rg() RETURNS VOID AS $$
DECLARE
  r RECORD;
  rgid INTEGER;
  rg_count INTEGER;
  uuid TEXT;
BEGIN
  FOR r in SELECT *
  FROM master_tbl LOOP
  
      -- Zunaechst alle RGs loeschen
      DELETE from rg_hilfsmassnahmen_tbl WHERE master_id = r.id;

      -- Hilfsmassnahme/Unterstuetzungsangebot 1
      IF r.hilfm_1 = 1
         OR r.hilfm_art_1 IS NOT NULL
         OR r.hilfm_inst_1 IS NOT NULL
         OR r.hilfm_einr_1 IS NOT NULL
         OR r.hilfm_start_1 IS NOT NULL
         OR r.hilfm_ende_1 IS NOT NULL
         OR r.hilfm_umf_1 IS NOT NULL
         
         OR r.hilfm_ziel_1_1 IS NOT NULL
         OR r.hilfm_zeit_1_1 != -1
         OR r.hilfm_erreicht_1_1 != -1
         
         OR r.hilfm_ziel_1_2 IS NOT NULL
         OR r.hilfm_zeit_1_2 != -1
         OR r.hilfm_erreicht_1_2 != -1
         
         OR r.hilfm_ziel_1_3 IS NOT NULL
         OR r.hilfm_zeit_1_3 != -1
         OR r.hilfm_erreicht_1_3 != -1
         
         OR r.hilfm_sf_1 IS NOT NULL THEN
         
	    uuid = generate_uuidgen();
            rgid = create_rg_hilfsmassnahmen_tbl(r.id, uuid);
            UPDATE rg_hilfsmassnahmen_tbl set
               hilfsmassnahmen_art = r.hilfm_art_1,
               hilfsmassnahmen_institution = r.hilfm_inst_1,
               hilfsmassnahmen_einrichtung = r.hilfm_einr_1,
               hilfsmassnahmen_start = r.hilfm_start_1,
               hilfsmassnahmen_ende = r.hilfm_ende_1,
               hilfsmassnahmen_umfang = r.hilfm_umf_1,
               
               hilfsmassnahmen_ziel_1 = r.hilfm_ziel_1_1,
               hilfsmassnahmen_zeit_1 = r.hilfm_zeit_1_1,
               hilfsmassnahmen_erreicht_1 = r.hilfm_erreicht_1_1,
               
               hilfsmassnahmen_ziel_2 = r.hilfm_ziel_1_2,
               hilfsmassnahmen_zeit_2 = r.hilfm_zeit_1_2,
               hilfsmassnahmen_erreicht_2 = r.hilfm_erreicht_1_2,
               
               hilfsmassnahmen_ziel_3 = r.hilfm_ziel_1_3,
               hilfsmassnahmen_zeit_3 = r.hilfm_zeit_1_3,
               hilfsmassnahmen_erreicht_3 = r.hilfm_erreicht_1_3,
               
               hilfsmassnahmen_schlussfolgerungen = r.hilfm_sf_1
            WHERE id = rgid;
      END IF;

      -- Hilfsmassnahme/Unterstuetzungsangebot 2 
      IF r.hilfm_2 = 1
         OR r.hilfm_art_2 IS NOT NULL
         OR r.hilfm_inst_2 IS NOT NULL
         OR r.hilfm_einr_2 IS NOT NULL
         OR r.hilfm_start_2 IS NOT NULL
         OR r.hilfm_ende_2 IS NOT NULL
         OR r.hilfm_umf_2 IS NOT NULL
         
         OR r.hilfm_ziel_2_1 IS NOT NULL
         OR r.hilfm_zeit_2_1 != -1
         OR r.hilfm_erreicht_2_1 != -1
         
         OR r.hilfm_ziel_2_2 IS NOT NULL
         OR r.hilfm_zeit_2_2 != -1
         OR r.hilfm_erreicht_2_2 != -1
         
         OR r.hilfm_ziel_2_3 IS NOT NULL
         OR r.hilfm_zeit_2_3 != -1
         OR r.hilfm_erreicht_2_3 != -1
         
         OR r.hilfm_sf_2 IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_hilfsmassnahmen_tbl(r.id, uuid);
            UPDATE rg_hilfsmassnahmen_tbl set
               hilfsmassnahmen_art = r.hilfm_art_2,
               hilfsmassnahmen_institution = r.hilfm_inst_2,
               hilfsmassnahmen_einrichtung = r.hilfm_einr_2,
               hilfsmassnahmen_start = r.hilfm_start_2,
               hilfsmassnahmen_ende = r.hilfm_ende_2,
               hilfsmassnahmen_umfang = r.hilfm_umf_2,
               
               hilfsmassnahmen_ziel_1 = r.hilfm_ziel_2_1,
               hilfsmassnahmen_zeit_1 = r.hilfm_zeit_2_1,
               hilfsmassnahmen_erreicht_1 = r.hilfm_erreicht_2_1,
               
               hilfsmassnahmen_ziel_2 = r.hilfm_ziel_2_2,
               hilfsmassnahmen_zeit_2 = r.hilfm_zeit_2_2,
               hilfsmassnahmen_erreicht_2 = r.hilfm_erreicht_2_2,
               
               hilfsmassnahmen_ziel_3 = r.hilfm_ziel_2_3,
               hilfsmassnahmen_zeit_3 = r.hilfm_zeit_2_3,
               hilfsmassnahmen_erreicht_3 = r.hilfm_erreicht_2_3,
               
               hilfsmassnahmen_schlussfolgerungen = r.hilfm_sf_2
            WHERE id = rgid;
      END IF;

      -- Hilfsmassnahme/Unterstuetzungsangebot 3
      IF r.hilfm_3 = 1
         OR r.hilfm_art_3 IS NOT NULL
         OR r.hilfm_inst_3 IS NOT NULL
         OR r.hilfm_einr_3 IS NOT NULL
         OR r.hilfm_start_3 IS NOT NULL
         OR r.hilfm_ende_3 IS NOT NULL
         OR r.hilfm_umf_3 IS NOT NULL
         
         OR r.hilfm_ziel_3_1 IS NOT NULL
         OR r.hilfm_zeit_3_1 != -1
         OR r.hilfm_erreicht_3_1 != -1
         
         OR r.hilfm_ziel_3_2 IS NOT NULL
         OR r.hilfm_zeit_3_2 != -1
         OR r.hilfm_erreicht_3_2 != -1
         
         OR r.hilfm_ziel_3_3 IS NOT NULL
         OR r.hilfm_zeit_3_3 != -1
         OR r.hilfm_erreicht_3_3 != -1
         
         OR r.hilfm_sf_3 IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_hilfsmassnahmen_tbl(r.id, uuid);
            UPDATE rg_hilfsmassnahmen_tbl set
               hilfsmassnahmen_art = r.hilfm_art_3,
               hilfsmassnahmen_institution = r.hilfm_inst_3,
               hilfsmassnahmen_einrichtung = r.hilfm_einr_3,
               hilfsmassnahmen_start = r.hilfm_start_3,
               hilfsmassnahmen_ende = r.hilfm_ende_3,
               hilfsmassnahmen_umfang = r.hilfm_umf_3,
               
               hilfsmassnahmen_ziel_1 = r.hilfm_ziel_3_1,
               hilfsmassnahmen_zeit_1 = r.hilfm_zeit_3_1,
               hilfsmassnahmen_erreicht_1 = r.hilfm_erreicht_3_1,
               
               hilfsmassnahmen_ziel_2 = r.hilfm_ziel_3_2,
               hilfsmassnahmen_zeit_2 = r.hilfm_zeit_3_2,
               hilfsmassnahmen_erreicht_2 = r.hilfm_erreicht_3_2,
               
               hilfsmassnahmen_ziel_3 = r.hilfm_ziel_3_3,
               hilfsmassnahmen_zeit_3 = r.hilfm_zeit_3_3,
               hilfsmassnahmen_erreicht_3 = r.hilfm_erreicht_3_3,
               
               hilfsmassnahmen_schlussfolgerungen = r.hilfm_sf_3
            WHERE id = rgid;
      END IF;


      -- Falls keine RGs angelegt wurden, eine neue erstellen
      SELECT COUNT(id) INTO rg_count FROM rg_hilfsmassnahmen_tbl WHERE master_id  = r.id;
      IF rg_count = 0 THEN
      	uuid = generate_uuidgen();
        rgid = create_rg_hilfsmassnahmen_tbl(r.id, uuid);
      END IF;

  END LOOP;
END;
$$ LANGUAGE plpgsql;
SET ROLE postgres;
SELECT insert_rg();
SET ROLE :db_adm;
DROP FUNCTION insert_rg();




-- Restore old function with its corresponding exception
CREATE OR REPLACE FUNCTION create_rg_hilfsmassnahmen_tbl(pid integer, nuuid char(36))
RETURNS integer
LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER AS
$$
DECLARE
    rid integer;
    mid integer;
BEGIN
    mid := pid;

    IF NOT isEditorOrStandin(mid) THEN
        RAISE EXCEPTION 'DS ID not session_user ID';
    END IF;

    INSERT INTO rg_hilfsmassnahmen_tbl (master_id) VALUES (pid);

    SELECT INTO rid currval('rg_hilfsmassnahmen_tbl_id_seq');

    IF nuuid IS NOT NULL THEN
        UPDATE rg_hilfsmassnahmen_tbl
        SET    uuid_id = nuuid
        WHERE  id = rid;
    ELSE
        PERFORM set_uuid('rg_hilfsmassnahmen_tbl', rid);
        
    END IF;

    RETURN rid;
END;
$$;


SET ROLE postgres;
ALTER TABLE master_tbl ENABLE TRIGGER USER;

-- ROLLBACK;
COMMIT;
